summaryrefslogtreecommitdiffstats
path: root/src/Authoring/Studio/Palettes/TimelineGraphicsView/RowMover.cpp
diff options
context:
space:
mode:
authorMahmoud Badri <mahmoud.badri@qt.io>2018-08-17 10:19:10 +0300
committerMahmoud Badri <mahmoud.badri@qt.io>2018-08-17 08:46:28 +0000
commitdf642248185e9bca8b71ad0fc33f129551685425 (patch)
treeaaeebf49c84f4edcc0309fdc8745aa502530cab4 /src/Authoring/Studio/Palettes/TimelineGraphicsView/RowMover.cpp
parente2ce7421489b0cb92d1d8cc55dac87f71cd818fe (diff)
Allow DnD qml streams to timeline layer, material and texture rows
- Allow DnD qml streams from the project palette to the timeline layer, material and texture rows to set sub-presentation for the row according to its type. - deleted 1 unused method. Task-number: QT3DS-2093 Change-Id: I4da1b315da0203cafec02783d3390991f233ecb7 Reviewed-by: Miikka Heikkinen <miikka.heikkinen@qt.io>
Diffstat (limited to 'src/Authoring/Studio/Palettes/TimelineGraphicsView/RowMover.cpp')
-rw-r--r--src/Authoring/Studio/Palettes/TimelineGraphicsView/RowMover.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/Authoring/Studio/Palettes/TimelineGraphicsView/RowMover.cpp b/src/Authoring/Studio/Palettes/TimelineGraphicsView/RowMover.cpp
index a2c2659b..1046996b 100644
--- a/src/Authoring/Studio/Palettes/TimelineGraphicsView/RowMover.cpp
+++ b/src/Authoring/Studio/Palettes/TimelineGraphicsView/RowMover.cpp
@@ -193,8 +193,8 @@ bool RowMover::isSourceRowsDescendant(RowTree *row) const
// i.e. when dragging from project or basic objects palettes
void RowMover::updateTargetRow(const QPointF &scenePos, EStudioObjectType rowType)
{
- // DnD a presentation from the project panel (to set it as a subpresentation)
- if (rowType == OBJTYPE_PRESENTATION) {
+ // DnD a presentation / Qml stream from the project panel (to set it as a subpresentation)
+ if (rowType == OBJTYPE_PRESENTATION || rowType == OBJTYPE_QML_STREAM) {
if (m_insertionTarget)
m_insertionTarget->setDnDState(RowTree::DnDState::None, RowTree::DnDState::SP_TARGET);
@@ -206,7 +206,7 @@ void RowMover::updateTargetRow(const QPointF &scenePos, EStudioObjectType rowTyp
m_insertType = Q3DStudio::DocumentEditorInsertType::LastChild;
if (rowAtMouse->rowType() == OBJTYPE_LAYER || rowAtMouse->rowType() == OBJTYPE_MATERIAL
- || rowAtMouse->rowType() == OBJTYPE_IMAGE) {
+ || rowAtMouse->rowType() == OBJTYPE_IMAGE) {
m_insertionTarget->setDnDState(RowTree::DnDState::SP_TARGET);
}
}